@@ -80,6 +80,7 @@ def bWriteFile(file, data, encoding='utf8', newline='\n'):
         f.write(data)
         f.flush()
         f.close()
+    return file
 
 
 def bWriteBinFile(file, data):
@@ -88,6 +89,7 @@ def bWriteBinFile(file, data):
         f.write(data)
         f.flush()
         f.close()
+    return file
 
 
 def bReadFile(file, encoding='utf8', newline='\n'):
@@ -689,57 +691,57 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
     return result, response
 
 
-def ptScrapy(urlList, parseFun, extendSettings=None):
+# def bScrapy(urlList, parseFun, extendSettings=None):
 
-    from scrapy.crawler import CrawlerProcess
-    from scrapy.utils.log import get_scrapy_root_handler
-    import scrapy.http
+#     from scrapy.crawler import CrawlerProcess
+#     from scrapy.utils.log import get_scrapy_root_handler
+#     import scrapy.http
 
-    resultList = []
-    resultUrlList = urlList[:]
+#     resultList = []
+#     resultUrlList = urlList[:]
 
-    class TempSpider(scrapy.Spider):
+#     class TempSpider(scrapy.Spider):
 
-        name = str(random.random())
-        start_urls = urlList
+#         name = str(random.random())
+#         start_urls = urlList
 
-        def parse(self, response):
-            itemList, urlList = parseFun(response)
-            if itemList:
-                resultList.extend(itemList)
-            if urlList:
-                for url in urlList:
-                    resultUrlList.append(url)
-                    yield scrapy.http.Request(url)
+#         def parse(self, response):
+#             itemList, urlList = parseFun(response)
+#             if itemList:
+#                 resultList.extend(itemList)
+#             if urlList:
+#                 for url in urlList:
+#                     resultUrlList.append(url)
+#                     yield scrapy.http.Request(url)
 
-    settings = {
-        'LOG_LEVEL': logging.INFO,
-        'LOG_FORMAT': '%(asctime)s %(levelname)-1s %(message)s',
-        'LOG_DATEFORMAT': '%Y-%m-%d %H:%M:%S',
-        'DOWNLOAD_TIMEOUT': 5,
-        'CONCURRENT_REQUESTS': 50,
-        'RETRY_HTTP_CODES': [514],
-        'RETRY_TIMES': 5,
-        # 'ITEM_PIPELINES': {
-        #    ptGetClassFullName( TempPipeline ): 300,
-        # },
-    }
-    if extendSettings:
-        for k, v in extendSettings.items():
-            settings[k] = v
+#     settings = {
+#         'LOG_LEVEL': logging.INFO,
+#         'LOG_FORMAT': '%(asctime)s %(levelname)-1s %(message)s',
+#         'LOG_DATEFORMAT': '%Y-%m-%d %H:%M:%S',
+#         'DOWNLOAD_TIMEOUT': 5,
+#         'CONCURRENT_REQUESTS': 50,
+#         'RETRY_HTTP_CODES': [514],
+#         'RETRY_TIMES': 5,
+#         # 'ITEM_PIPELINES': {
+#         #    ptGetClassFullName( TempPipeline ): 300,
+#         # },
+#     }
+#     if extendSettings:
+#         for k, v in extendSettings.items():
+#             settings[k] = v
 
-    process = CrawlerProcess(settings)
-    process.crawl(TempSpider)
-    process.start()
+#     process = CrawlerProcess(settings)
+#     process.crawl(TempSpider)
+#     process.start()
 
-    rootHandler = get_scrapy_root_handler()
-    if rootHandler:
-        rootHandler.close()
+#     rootHandler = get_scrapy_root_handler()
+#     if rootHandler:
+#         rootHandler.close()
 
-    # 函数执行后再调用logging都会有2次显示在控制台
-    logging.getLogger().handlers = []
+#     # 函数执行后再调用logging都会有2次显示在控制台
+#     logging.getLogger().handlers = []
 
-    return resultList, resultUrlList
+#     return resultList, resultUrlList
 
 
 if __name__ == '__main__':
